netapp_ontap.resources.azure_key_vault API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.azure_key_vault`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

Azure Key Vault (AKV) is a cloud key management service (KMS) that provides a secure store for secrets. This feature allows ONTAP to securely store its encryption keys using AKV. In order to use AKV with ONTAP, you must first deploy an Azure application with the appropriate access to an AKV and then provide ONTAP with the necessary details, such as key vault name, application ID so that ONTAP can communicate with the deployed Azure application. The properties "state", "azure_reachability" and "ekmip_reachability" are considered advanced properties and are populated only when explicitly requested.

## Examples

### Enabling an AKV configuration for an SVM using the certificate authentication method

The example AKV configuration is enabled for a specific SVM. Note the return_records=true query parameter is used to obtain the newly created key-manager keystore configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault()
        resource.svm = {"uuid": "4f7abf4c-9a07-11ea-8d52-005056bbeba5"}
        resource.client_id = "client1"
        resource.tenant_id = "tenant1"
        resource.name = "https:://mykeyvault.vault.azure.net/"
        resource.key_id = "https://keyvault-test.vault.azure.net/keys/key1/a8e619fd8f234db3b0b95c59540e2a74"
        resource.client_certificate = "<CERTIFICATE-CONTENT>"
        resource.post(hydrate=True)
        print(resource)

Try it out

    AzureKeyVault(
        {
            "tenant_id": "tenant1",
            "name": "https:://mykeyvault.vault.azure.net/",
            "client_id": "client1",
            "_links": {
                "self": {
                    "href": "/api/security/azure-key-vaults/024cd3cf-9a08-11ea-8d52-005056bbeba5"
                }
            },
            "key_id": "https://keyvault-test.vault.azure.net/keys/key1/a8e619fd8f234db3b0b95c59540e2a74",
            "uuid": "024cd3cf-9a08-11ea-8d52-005056bbeba5",
            "svm": {"name": "vs0", "uuid": "4f7abf4c-9a07-11ea-8d52-005056bbeba5"},
        }
    )

### Creating an inactive AKV configuration for an SVM using the client secret authentication method

The example AKV configuration is created for a specific SVM but is not enabled. Note the create_inactive=true parameter that is used to indicate that the configuration should be created but not enabled. Note the return_records=true query parameter is used to obtain the newly created key-manager keystore configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault()
        resource.svm = {"uuid": "4f7abf4c-9a07-11ea-8d52-005056bbeba5"}
        resource.configuration = {"name": "myConfiguration"}
        resource.client_id = "client1"
        resource.tenant_id = "tenant1"
        resource.name = "https:://mykeyvault.vault.azure.net/"
        resource.key_id = "https://keyvault-test.vault.azure.net/keys/key1/a8e619fd8f234db3b0b95c59540e2a74"
        resource.client_secret = "myclientPwd"
        resource.post(hydrate=True, create_inactive=True)
        print(resource)

Try it out

    AzureKeyVault(
        {
            "tenant_id": "tenant1",
            "configuration": {"name": "myConfiguration"},
            "name": "https:://mykeyvault.vault.azure.net/",
            "client_id": "client1",
            "_links": {
                "self": {
                    "href": "/api/security/azure-key-vaults/85619643-9a06-11ea-8d52-005056bbeba5"
                }
            },
            "key_id": "https://keyvault-test.vault.azure.net/keys/key1/a8e619fd8f234db3b0b95c59540e2a74",
            "uuid": "85619643-9a06-11ea-8d52-005056bbeba5",
        }
    )

### Retrieving the AKVs configured for all clusters and SVMs

The following example shows how to retrieve all configured AKVs along with their configurations.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(AzureKeyVault.get_collection(fields="*")))

Try it out

    [
        AzureKeyVault(
            {
                "tenant_id": "tenant1",
                "authentication_method": "client_secret",
                "configuration": {
                    "name": "default",
                    "uuid": "024cd3cf-9a08-11ea-8d52-005056bbeba5",
                },
                "name": "https:://mykeyvault.vault.azure.net/",
                "client_id": "client1",
                "enabled": True,
                "_links": {
                    "self": {
                        "href": "/api/security/azure-key-vaults/024cd3cf-9a08-11ea-8d52-005056bbeba5"
                    }
                },
                "key_id": "https://keyvault-test.vault.azure.net/keys/key1/a8e619fd8f234db3b0b95c59540e2a74",
                "uuid": "024cd3cf-9a08-11ea-8d52-005056bbeba5",
                "scope": "svm",
                "svm": {"name": "vs0", "uuid": "4f7abf4c-9a07-11ea-8d52-005056bbeba5"},
            }
        ),
        AzureKeyVault(
            {
                "tenant_id": "tenant1",
                "authentication_method": "certificate",
                "configuration": {
                    "name": "new-config",
                    "uuid": "85619643-9a06-11ea-8d52-005056bbeba5",
                },
                "name": "https:://mykeyvault.vault.azure.net/",
                "client_id": "client1",
                "enabled": False,
                "_links": {
                    "self": {
                        "href": "/api/security/azure-key-vaults/85619643-9a06-11ea-8d52-005056bbeba5"
                    }
                },
                "key_id": "https://keyvault-test.vault.azure.net/keys/key1/a8e619fd8f234db3b0b95c59540e2a74",
                "uuid": "85619643-9a06-11ea-8d52-005056bbeba5",
                "scope": "cluster",
            }
        ),
    ]

### Retrieving a specific AKV configuration

The following example retrieves a specific AKV configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.get(fields="*")
        print(resource)

Try it out

    AzureKeyVault(
        {
            "tenant_id": "tenant1",
            "authentication_method": "client_secret",
            "configuration": {
                "name": "default",
                "uuid": "85619643-9a06-11ea-8d52-005056bbeba5",
            },
            "name": "https:://mykeyvault.vault.azure.net/",
            "client_id": "client1",
            "enabled": True,
            "_links": {
                "self": {
                    "href": "/api/security/azure-key-vaults/85619643-9a06-11ea-8d52-005056bbeba5"
                }
            },
            "key_id": "https://keyvault-test.vault.azure.net/keys/key1/a8e619fd8f234db3b0b95c59540e2a74",
            "uuid": "85619643-9a06-11ea-8d52-005056bbeba5",
            "scope": "cluster",
        }
    )

### Retrieving the advanced properties of a specific, enabled AKV configuration

The following example retrieves the advanced properties of a specific enabled AKV configuration (inactive AKV configurations do not have these advanced properties).

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.get(fields='state,azure_reachability,ekmip_reachability"')
        print(resource)

### Updating the client secret of a specific AKV configuration

The following example updates the client secret of a specific AKV configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.client_secret = "<NEW-SECRET>"
        resource.patch()

### Updating the client certificate and key of a specific AKV configuration

The following example updates the client certificate and key of a configured AKV for a specific AKV configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.client_certificate = "<CERTIFICATE-CONTENT>"
        resource.patch()

### Deleting a specific AKV configuration

The following example deletes a specific, enabled AKV.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.delete()

### Restoring the keys for a specific AKV configuration

The following example restores all the keys of a specific AKV configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.restore()

Try it out

    AzureKeyVault({})

### Rekeying the internal key for a specific AKV configuration

The following example rekeys the internal key of a specific AKV configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AzureKeyVault

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AzureKeyVault(uuid="85619643-9a06-11ea-8d52-005056bbeba5")
        resource.rekey_internal()

Try it out

    AzureKeyVault({})

## Classes

`class AzureKeyVault (*args, **kwargs)`

  Allows interaction with AzureKeyVault objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all AzureKeyVault resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('AzureKeyVault')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes an AKV configuration.

    ### Related ONTAP commands

    - `security key-manager external azure disable`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent AzureKeyVault resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves AKVs configured for all clusters and SVMs.

    ### Related ONTAP commands

    - `security key-manager external azure show`
    - `security key-manager external azure check`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves AKVs configured for all clusters and SVMs.

    ### Related ONTAP commands

    - `security key-manager external azure show`
    - `security key-manager external azure check`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('AzureKeyVault')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the AKV configuration.

    ### Optional properties

    - `client_secret` or `client_certificate` - New secret or new PKCS12 certificate used to prove the application's identity to the AKV.
    - `proxy_type` - Type of proxy (http, https etc.) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `port` - Authorization server and vault port number.
    - `oauth_host` - Open authorization server host name.
    - `vault_host` - AKV host subdomain.
    - `verify_host` - Verify the identity of the AKV host name.
    - `verify_ip` - Verify the identity of the AKV IP address.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.
    - `client_id` - Application (client) ID of the deployed Azure application with appropriate access to an AKV.
    - `tenant_id` - Directory (tenant) ID of the deployed Azure application with appropriate access to an AKV.
    - `skip_verification` - Skip the verification of the updated credentials, set to true to bypass the verification. The default value is false.

    ### Related ONTAP commands

    - `security key-manager external azure update-client-secret`
    - `security key-manager external azure update-credentials`
    - `security key-manager external azure update-config`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('AzureKeyVault')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[AzureKeyVault], NetAppResponse]`

    Configures the AKV configuration for all clusters and SVMs.

    ### Required properties:

    - `svm.uuid` or `svm.name` - Existing SVM in which to create a AKV.
    - `client_id` - Application (client) ID of the deployed Azure application with appropriate access to an AKV.
    - `tenant_id` - Directory (tenant) ID of the deployed Azure application with appropriate access to an AKV.
    - `client_secret` or `client_certificate` - Secret or PKCS12 Certificate used by the application to prove its identity to AKV.
    - `key_id`- Key Identifier of AKV encryption key.
    - `name` - Name of the deployed AKV used by ONTAP for storing keys.

    ### Optional properties:

    - `port` - Authorization server and vault port number.
    - `oauth_host` - Open authorization server host name.
    - `vault_host` - AKV host subdomain.
    - `proxy_type` - Type of proxy (http, https etc.) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.
    - `configuration.name` - The configuration name to use when also setting the `create_inactive` flag.

    ### Optional parameters:

    - `create_inactive` - Create an AKV configuration without enabling it. This flag is set to "false" by default.

    ### Related ONTAP commands

    - `security key-manager external azure enable`
    - `security key-manager external azure create-config`
    - `security key-manager external azure update-config`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes an AKV configuration.

    ### Related ONTAP commands

    - `security key-manager external azure disable`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the AKV configuration for the SVM specified by the UUID.

    ### Related ONTAP commands

    - `security key-manager external azure show`
    - `security key-manager external azure check`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates the AKV configuration.

    ### Optional properties

    - `client_secret` or `client_certificate` - New secret or new PKCS12 certificate used to prove the application's identity to the AKV.
    - `proxy_type` - Type of proxy (http, https etc.) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `port` - Authorization server and vault port number.
    - `oauth_host` - Open authorization server host name.
    - `vault_host` - AKV host subdomain.
    - `verify_host` - Verify the identity of the AKV host name.
    - `verify_ip` - Verify the identity of the AKV IP address.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.
    - `client_id` - Application (client) ID of the deployed Azure application with appropriate access to an AKV.
    - `tenant_id` - Directory (tenant) ID of the deployed Azure application with appropriate access to an AKV.
    - `skip_verification` - Skip the verification of the updated credentials, set to true to bypass the verification. The default value is false.

    ### Related ONTAP commands

    - `security key-manager external azure update-client-secret`
    - `security key-manager external azure update-credentials`
    - `security key-manager external azure update-config`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Configures the AKV configuration for all clusters and SVMs.

    ### Required properties:

    - `svm.uuid` or `svm.name` - Existing SVM in which to create a AKV.
    - `client_id` - Application (client) ID of the deployed Azure application with appropriate access to an AKV.
    - `tenant_id` - Directory (tenant) ID of the deployed Azure application with appropriate access to an AKV.
    - `client_secret` or `client_certificate` - Secret or PKCS12 Certificate used by the application to prove its identity to AKV.
    - `key_id`- Key Identifier of AKV encryption key.
    - `name` - Name of the deployed AKV used by ONTAP for storing keys.

    ### Optional properties:

    - `port` - Authorization server and vault port number.
    - `oauth_host` - Open authorization server host name.
    - `vault_host` - AKV host subdomain.
    - `proxy_type` - Type of proxy (http, https etc.) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.
    - `configuration.name` - The configuration name to use when also setting the `create_inactive` flag.

    ### Optional parameters:

    - `create_inactive` - Create an AKV configuration without enabling it. This flag is set to "false" by default.

    ### Related ONTAP commands

    - `security key-manager external azure enable`
    - `security key-manager external azure create-config`
    - `security key-manager external azure update-config`

    ### Learn more

    - `DOC /security/azure-key-vaults`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def rekey_external (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Rekeys the external key in the key hierarchy for an SVM with an AKV configuration.

    ### Required properties

    - `key_id` - Key identifier of the new AKV key encryption key.

    ### Related ONTAP commands

    - `security key-manager external azure rekey-external`

    Perform a custom action on this resource which is not a simple CRUD action

    ## Args

    `path`
      The action verb for this request. This will be added as a postfix to the instance location of the resource.
    `body`
      The body of the action request. This should be a Resource instance. The connection and URL will be determined based on the values from this object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def rekey_internal (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Rekeys the internal key in the key hierarchy for an SVM with an AKV configuration.

    ### Related ONTAP commands

    - `security key-manager external azure rekey-internal`

    Perform a custom action on this resource which is not a simple CRUD action

    ## Args

    `path`
      The action verb for this request. This will be added as a postfix to the instance location of the resource.
    `body`
      The body of the action request. This should be a Resource instance. The connection and URL will be determined based on the values from this object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def restore (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Restore the keys for an SVM from a configured AKV.

    ### Related ONTAP commands

    - `security key-manager external azure restore`

    Perform a custom action on this resource which is not a simple CRUD action

    ## Args

    `path`
      The action verb for this request. This will be added as a postfix to the instance location of the resource.
    `body`
      The body of the action request. This should be a Resource instance. The connection and URL will be determined based on the values from this object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class AzureKeyVaultSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AzureKeyVault object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `authentication_method: str GET`

    Authentication method for the AKV instance.

    Valid choices:

    - client_secret
    - certificate
  `azure_reachability: AzureKeyVaultConnectivity GET`

    Indicates whether or not the AKV service is reachable from all the nodes in the cluster. This is an advanced property; there is an added computational cost to retrieving its value. The property is not populated for either a collection GET or an instance GET unless it is explicitly requested using the `fields` query parameter or GET for all advanced properties is enabled.

  `client_certificate: str POST PATCH`

    PKCS12 Certificate used by the application to prove its identity to AKV.

    Example:

  `client_id: str GET POST PATCH`

    Application client ID of the deployed Azure application with appropriate access to an AKV.

    Example: aaaaaaaa-bbbb-aaaa-bbbb-aaaaaaaaaaaa

  `client_secret: str POST PATCH`

    Secret used by the application to prove its identity to AKV.

    Example: abcdef

  `configuration: SecurityKeystoreConfiguration GET POST`

    Security keystore object reference.

  `ekmip_reachability: List[AwsKmsEkmipReachability] GET`

    Provides the connectivity status for the given SVM on the given node to all EKMIP servers configured on all nodes of the cluster. This is an advanced property; there is an added computational cost to retrieving its value. The property is not populated for either a collection GET or an instance GET unless it is explicitly requested using the `fields` query parameter or GET for all advanced properties is enabled.

  `enabled: bool GET`

    Indicates whether the configuration is enabled.

  `key_id: str GET POST`

    Key Identifier of AKV key encryption key.

    Example: https://keyvault1.vault.azure.net/keys/key1/12345678901234567890123456789012

  `links: SelfLink GET`

    The links field of the azure_key_vault.

  `name: str GET POST`

    Name of the deployed AKV that will be used by ONTAP for storing keys.

    Example: https://kmip-akv-keyvault.vault.azure.net/

  `oauth_host: str GET POST PATCH`

    Open authorization server host name.

    Example: login.microsoftonline.com

  `port: Size GET POST PATCH`

    Authorization server and vault port number.

    Example: 443

  `proxy_host: str GET POST PATCH`

    Proxy host.

    Example: proxy.eng.com

  `proxy_password: str POST PATCH`

    Proxy password. Password is not audited.

    Example: proxypassword

  `proxy_port: Size GET POST PATCH`

    Proxy port.

    Example: 1234

  `proxy_type: str GET POST PATCH`

    Type of proxy.

    Valid choices:

    - http
    - https
  `proxy_username: str GET POST PATCH`

    Proxy username.

    Example: proxyuser

  `scope: str GET`

    Set to "svm" for interfaces owned by an SVM. Otherwise, set to "cluster".

    Valid choices:

    - svm
    - cluster
  `skip_verification: bool GET POST PATCH`

    Set to true to skip the verification of the updated user credentials when updating credentials. The default value is false.

    Example: false

  `state: AzureKeyVaultState GET`

    Indicates whether or not the AKV wrapped internal key is available cluster wide. This is an advanced property; there is an added computational cost to retrieving its value. The property is not populated for either a collection GET or an instance GET unless it is explicitly requested using the `fields` query parameter or GET for all advanced properties is enabled.

  `svm: Svm GET POST`

    The svm field of the azure_key_vault.

  `tenant_id: str GET POST PATCH`

    Directory (tenant) ID of the deployed Azure application with appropriate access to an AKV.

    Example: zzzzzzzz-yyyy-zzzz-yyyy-zzzzzzzzzzzz

  `uuid: str GET`

    A unique identifier for the Azure Key Vault (AKV).

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412

  `vault_host: str GET POST PATCH`

    AKV host subdomain.

    Example: vault.azure.net

  `verify_host: bool GET PATCH`

    Verify the identity of the AKV host name.

    Example: false

  `verify_ip: bool GET PATCH`

    Verify the identity of the AKV IP address.

    Example: false